.TH STOD 1L "12 May 1992"
.\"======================================================================
.SH "NAME"
stod \- convert Fortran program from single-precision to double-precision
.\"======================================================================
.SH "SYNOPSIS"
.B stod
< infile >outfile
.PP
.B stod
copies its standard input to standard output,
converting Fortran single-precision constants,
built-in functions, and type declarations to
double precision.
.PP
Floating-point FORMAT specifications are left
intact; on some ancient systems, they may require
modifications.  They do
.I not
under the rules of Fortran 77.
.PP
Leading tabs are correctly interpreted according
to common extended Fortran rules.
.PP
.B stod
recognizes all of the standard Fortran 77
single- and double-precision functions,
as well as the pair
.B "rand/drand"
(UNIX pseudo-random number generators), and
the pair
.B "r1mach/d1mach"
from the PORT library framework.
.PP
.BR stod 's
other purpose is to demonstrate a modest
.BR lex (1)
program.
.\"======================================================================
.SH "BUGS"
Undeclared variables are not type-converted.  To find 
such instances, use the Extended PFORT Verifier, 
.BR pfort (1),
or the Fortran checker,
.BR ftnchek (1).
Some UNIX Fortran compilers have a compile-time
option, usually called
.IR \-u ,
to flag undeclared variables.
.PP
Text beyond column 72 is discarded when
lines are collected into Fortran statements.
.PP
.B stod
does not handle embedded ASCII tab characters
correctly when long lines are to be broken.  A
Fortran-sensitive detabbing utility should be
applied first if the input file possibly contains
embedded tabs.  Note that
.BR expand (1)
.I cannot
be used to do this job correctly!
.PP
Mixed-precision code may not be converted correctly.
For example, 
.B "SNGL(DFLOAT(N))"
will become
.BR "DBLE(DFLOAT(N))" ,
which is syntactically incorrect.
.PP
Functions and variables of type 
.B COMPLEX
are not converted, because Fortran 77 does not
define a double precision complex type.  Complex
constants will be converted, however, since their
real and imaginary parts look like normal
floating-point values.
.\"======================================================================
.SH "SEE ALSO"
.BR dtos (1),
.BR ftnchek (1),
.BR lex (1),
.BR pfort (1).
.\"======================================================================
.SH "AUTHOR"
Nelson H. F. Beebe, Ph.D.
.br
Center for Scientific Computing
.br
Department of Mathematics
.br
South Physics Building
.br
University of Utah
.br
Salt Lake City, UT 84112
.br
Tel: (801) 581-5254
.br
FAX: (801) 581-4148
.br
Email: <beebe@math.utah.edu>
.\"==============================[The End]==============================
